package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WorkerLevelLogMapper;
import com.ruoyi.system.domain.WorkerLevelLog;
import com.ruoyi.system.service.IWorkerLevelLogService;

/**
 * 师傅等级每月记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class WorkerLevelLogServiceImpl implements IWorkerLevelLogService 
{
    @Autowired
    private WorkerLevelLogMapper workerLevelLogMapper;

    /**
     * 查询师傅等级每月记录
     * 
     * @param id 师傅等级每月记录主键
     * @return 师傅等级每月记录
     */
    @Override
    public WorkerLevelLog selectWorkerLevelLogById(Integer id)
    {
        return workerLevelLogMapper.selectWorkerLevelLogById(id);
    }

    /**
     * 查询师傅等级每月记录列表
     * 
     * @param workerLevelLog 师傅等级每月记录
     * @return 师傅等级每月记录
     */
    @Override
    public List<WorkerLevelLog> selectWorkerLevelLogList(WorkerLevelLog workerLevelLog)
    {
        return workerLevelLogMapper.selectWorkerLevelLogList(workerLevelLog);
    }

    /**
     * 新增师傅等级每月记录
     * 
     * @param workerLevelLog 师傅等级每月记录
     * @return 结果
     */
    @Override
    public int insertWorkerLevelLog(WorkerLevelLog workerLevelLog)
    {
        return workerLevelLogMapper.insertWorkerLevelLog(workerLevelLog);
    }

    /**
     * 修改师傅等级每月记录
     * 
     * @param workerLevelLog 师傅等级每月记录
     * @return 结果
     */
    @Override
    public int updateWorkerLevelLog(WorkerLevelLog workerLevelLog)
    {
        return workerLevelLogMapper.updateWorkerLevelLog(workerLevelLog);
    }

    /**
     * 批量删除师傅等级每月记录
     * 
     * @param ids 需要删除的师傅等级每月记录主键
     * @return 结果
     */
    @Override
    public int deleteWorkerLevelLogByIds(Integer[] ids)
    {
        return workerLevelLogMapper.deleteWorkerLevelLogByIds(ids);
    }

    /**
     * 删除师傅等级每月记录信息
     * 
     * @param id 师傅等级每月记录主键
     * @return 结果
     */
    @Override
    public int deleteWorkerLevelLogById(Integer id)
    {
        return workerLevelLogMapper.deleteWorkerLevelLogById(id);
    }
}
