package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WorkerLevelLog;
import com.ruoyi.system.service.IWorkerLevelLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 师傅等级每月记录Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/WorkerLevelLog")
public class WorkerLevelLogController extends BaseController
{
    @Autowired
    private IWorkerLevelLogService workerLevelLogService;

    /**
     * 查询师傅等级每月记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(WorkerLevelLog workerLevelLog)
    {
        startPage();
        List<WorkerLevelLog> list = workerLevelLogService.selectWorkerLevelLogList(workerLevelLog);
        return getDataTable(list);
    }

    /**
     * 导出师傅等级每月记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:export')")
    @Log(title = "师傅等级每月记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WorkerLevelLog workerLevelLog)
    {
        List<WorkerLevelLog> list = workerLevelLogService.selectWorkerLevelLogList(workerLevelLog);
        ExcelUtil<WorkerLevelLog> util = new ExcelUtil<WorkerLevelLog>(WorkerLevelLog.class);
        util.exportExcel(response, list, "师傅等级每月记录数据");
    }

    /**
     * 获取师傅等级每月记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(workerLevelLogService.selectWorkerLevelLogById(id));
    }

    /**
     * 新增师傅等级每月记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:add')")
    @Log(title = "师傅等级每月记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WorkerLevelLog workerLevelLog)
    {
        return toAjax(workerLevelLogService.insertWorkerLevelLog(workerLevelLog));
    }

    /**
     * 修改师傅等级每月记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:edit')")
    @Log(title = "师傅等级每月记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WorkerLevelLog workerLevelLog)
    {
        return toAjax(workerLevelLogService.updateWorkerLevelLog(workerLevelLog));
    }

    /**
     * 删除师傅等级每月记录
     */
    @PreAuthorize("@ss.hasPermi('system:WorkerLevelLog:remove')")
    @Log(title = "师傅等级每月记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(workerLevelLogService.deleteWorkerLevelLogByIds(ids));
    }
}
